@@ -299,6 +299,7 @@ void CameraUI::SetResegText(QString text){
 void CameraUI::SetOCRText(QString text){
     if(text == ""){
         text = " "; // Needed to prevent crashing
+        ShowNoResultsDialog();
     }
 
     // Reset the alternative candidates table, set the OCRdText to whatever the server returned
@@ -801,6 +802,21 @@ void CameraUI::ShowTimedOutDiscDialog(OCRRequest * req){
     ViewPhoto();
 }
 
+void CameraUI::ShowNoResultsDialog(){
+    // Don't need to delete here. Will be deleted on new send request.
+    ocr_req->blockSignals(true);
+    QDialog * noResultsDialog = new QDialog();
+    noResultsDialog->setWindowTitle("No Recognized Characters");
+    noResultsDialog->setModal(true);
+    QLabel l("No characters recognized. Please try a different image.", noResultsDialog);
+    l.setWordWrap(true);
+    l.show();
+    noResultsDialog->exec();
+    noResultsDialog->deleteLater();
+    m_just_timed_out = true;
+    ViewPhoto();
+}
+
 void CameraUI::ShowErrorConnectingDialog(OCRRequest *req){
     // Don't need to delete here. Will be deleted on new send request.
     ocr_req->blockSignals(true);
